summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorChristian Heimes <christian@python.org>2013-02-15 14:16:39 +0100
committerChristian Heimes <christian@python.org>2013-02-15 14:16:39 +0100
commitf886b726409e51781fe7f005e590fd7fae28a4dc (patch)
tree2b417400c20d3fecc18ae2ef7b379927f05b3bae
parent30bccd169332e236721ccd28ff354aa097d43c24 (diff)
downloaddefusedxml-git-f886b726409e51781fe7f005e590fd7fae28a4dc.tar.gz
document no decompression bomb protection in lxml
-rw-r--r--defusedxml/lxml.py5
1 files changed, 2 insertions, 3 deletions
diff --git a/defusedxml/lxml.py b/defusedxml/lxml.py
index 45c6f30..94b497c 100644
--- a/defusedxml/lxml.py
+++ b/defusedxml/lxml.py
@@ -3,9 +3,9 @@
# Copyright (c) 2013 by Christian Heimes <christian@python.org>
# Licensed to PSF under a Contributor Agreement.
# See http://www.python.org/psf/license for licensing details.
-"""Example code for lxml.etree
-
+"""Example code for lxml.etree protection
+The code has NO protection against decompression bombs.
"""
from __future__ import print_function, absolute_import
@@ -71,7 +71,6 @@ class GlobalParserTLS(threading.local):
'resolve_entities': False,
#'remove_comments': True,
#'remove_pis': True,
-
}
element_class = RestrictedElement